@@ -5,9 +5,11 @@ import traceback
 
 from . import __version__
 from . import configure
+from . import auth
 from . import publish
 from . import subscribe
 from . import version
+from . import list_topics
 from .utils import cli as cli_utils
 
 
@@ -42,6 +44,9 @@ def set_up_cli():
     )
     configure._add_parser_args(p)
 
+    p = cli_utils.append_subparser(subparser, "auth", auth._main)
+    auth._add_parser_args(p)
+
     p = cli_utils.append_subparser(subparser, "publish", publish._main)
     publish._add_parser_args(p)
 
@@ -50,14 +55,40 @@ def set_up_cli():
 
     p = cli_utils.append_subparser(subparser, "version", version._main)
 
+    p = cli_utils.append_subparser(subparser, "list-topics", list_topics._main)
+    list_topics._add_parser_args(p)
+
     return parser
 
 
+def check_auth_data(prog_name):
+    """Advise the user on getting/configuring credential data
+    """
+
+    advice = """
+No valid credential data found
+You can get a credential from https://my.hop.scimma.org
+To load your credential, run `hop auth add`
+"""
+
+    try:
+        auth.load_auth()
+    except FileNotFoundError:
+        print(advice)
+    except Exception as ex:
+        print(prog_name + ":", ex, file=sys.stderr)
+        print(advice)
+
+
 def main():
     signal.signal(signal.SIGINT, signal.SIG_DFL)
 
     parser = set_up_cli()
-    args = parser.parse_args()
+    try:
+        args = parser.parse_args()
+    except SystemExit:
+        check_auth_data(parser.prog)
+        raise
     try:
         args.func(args)
     except Exception as ex:
