@@ -1,4 +1,5 @@
 import sys
+import json
 
 from . import cli
 from . import io
@@ -38,5 +39,8 @@ def _main(args):
                 assert args.format == io.Deserializer.BLOB.name, \
                     "piping/redirection only allowed for BLOB formats"
 
-                for message in messages:
-                    s.write(loader.load(message))
+                try:
+                    for message in messages:
+                        s.write(loader.load(json.loads(message)))
+                except json.decoder.JSONDecodeError as err:
+                    raise ValueError("Blob messages must be valid JSON") from err
